@@ -2,7 +2,7 @@
 #' @title add flextable into a PowerPoint slide
 #' @description add a flextable as a new shape in the current slide.
 #'
-#' These functions will be deprecated in the next release and
+#' These functions is deprecated and
 #' method \code{\link[officer]{ph_with}} should be used instead.
 #' @note
 #' The width and height of the table can not be set with this function. Use
@@ -16,7 +16,7 @@
 #' is not unique in the current slide, e.g. two placeholders with type 'body'.
 #' @importFrom officer ph_location_type
 ph_with_flextable <- function( x, value, type = "body", index = 1 ){
-  # .Deprecated(new = "officer::ph_with")
+  .Deprecated(new = "officer::ph_with")
   stopifnot(inherits(x, "rpptx"))
   ph_with(x, value, location = ph_location_type(type = type, id = index))
 }
