@@ -60,6 +60,13 @@ ft <- align(ft, align = "center", part = "body")
 ## ----echo=FALSE---------------------------------------------------------------
 ft
 
+## -----------------------------------------------------------------------------
+ft <- flextable(head(mtcars))
+line_spacing(ft, space = 1)
+
+## -----------------------------------------------------------------------------
+line_spacing(ft, space = 1.5)
+
 ## -----------------------------------------------------------------------------
 library(officer)
 big_border = fp_border(color="orange", width = 2)
